@@ -117,14 +117,20 @@ class Slackard(object):
                                      icon_url=self.boticon)
 
     def upload(self, file, filename=None, title=None):
-        channels = self.chan_id
         if title is None:
             title = ''
         title = '{} (Upload by {})'.format(title, self.botname)
-        self.slack.files.upload(file, channels=channels,
+        self.slack.files.upload(file, channels=self.chan_id,
                                 filename=filename,
                                 title=title)
 
+    def set_topic(self, topic):
+        self.slack.channels.set_topic(channel=self.chan_id, topic=topic)
+
+    def channel_info(self):
+        info = self.slack.channels.info(channel=self.chan_id)
+        return info.body['channel']
+
     def run(self):
         self._init_connection()
         self._import_plugins()
@@ -268,9 +274,9 @@ def main():
             print('Delaying for {} seconds...'.format(delay))
             time.sleep(delay)
             bot._init_connection()
-        #except Exception as e:
-        #    print('Unhandled exception: {}'.format(e.message))
-        #    sys.exit(1)
+        except Exception as e:
+            print('Unhandled exception: {}'.format(e.message))
+            sys.exit(1)
 
 
 if __name__ == '__main__':
